LogHoundClient class

Fire-and-forget client for emitting structured records as VM Service events.

Constructors

LogHoundClient({LogHoundVmServiceEventSink? postEvent, String eventKind = logHoundVmServiceEventKind})
Creates a client that posts records to postEvent.

Properties

eventKind String
VM Service extension event kind used by this client.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Kept for API symmetry with owned-resource transports.
flush() Future<void>
Kept for API symmetry with async transports.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(Map<String, Object?> record) → void
Emits record as a VM Service extension event and swallows sink failures.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited