LogHoundVmServiceEvent class

One extension event received from a Dart VM Service stream.

Constructors

LogHoundVmServiceEvent({required String? kind, required Object? data})
Creates a VM Service extension event wrapper.
const

Properties

data Object?
The VM Service extension event payload.
final
hashCode int
The hash code for this object.
no setterinherited
kind String?
The VM Service extension event kind.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited