LogHoundCapture class
Controls which development signals LogHound.run captures automatically.
Constructors
Properties
- actions → bool
-
Whether semantic action helpers are expected to be used.
final
- errors → bool
-
Whether to capture uncaught zone errors.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- http → bool
-
Whether HTTP helper events are expected to be used.
final
- prints → bool
-
Whether to capture
printcalls from the app zone.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionLifecycle → bool
-
Whether to send a
session.startrecord.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited